@@ -32,12 +32,12 @@ def create_compilation_songs(data, job_id, mf_server):
                 song['local']=''
                 if arr_tmp[0] == "youtube":#youtube
                     song['local']=download_audio(arr_tmp[2])
-                if arr_tmp[0] == "gdrive":#gdrive
-                    tmp = song['uri'].replace("gdrive:track:", "")
-                    song['local'] = download_file(tmp, ext="mp3")
                 if arr_tmp[0] == "direct":#direct
                     tmp=song['uri'].replace("direct:track:","")
-                    song['local'] = download_file(tmp)
+                    ext = None
+                    if "gdrive" in tmp:
+                        ext="mp3"
+                    song['local'] = download_file(tmp,ext=ext)
                 if arr_tmp[0] == "deezer":#deezer
                     song_info=requests.get("http://source.automusic.win/deezer/track/get/"+arr_tmp[2], timeout=180).json()
                     song['local']=download_file(song_info['url_128'])
